@@ -65,7 +65,7 @@ def test_create_checkout_session_already_paid(
     auth_client, paid_plan, user, mock_stripe_checkout
 ):
     """A User with an existing subscription may not access the create_checkout_session endpoint."""
-    factories.set_customer_paying(user.customer)
+    factories.StripeSubscriptionFactory(customer=user.customer)
     url = reverse(
         "billing:create_checkout_session",
         kwargs={"slug": paid_plan.slug, "pk": paid_plan.id},
@@ -147,94 +147,3 @@ def test_create_subscription_changed_email(
     assert settings.CHECKOUT_SUCCESS_URL == response.url
     assert mock_stripe_customer.modify.call_count == 1
     assert mock_stripe_customer.modify.call_args.kwargs["email"] == user.email
-
-
-def test_webhook_create_subscription(
-    client, user, paid_plan, session, mock_stripe_checkout
-):
-    """checkout.session.completed should set the customer_id, plan, current_period_end,
-    payment_state and card_info"""
-    url = reverse("billing:stripe_webhook")
-    payload = {
-        "id": "evt_test",
-        "object": "event",
-        "type": "checkout.session.completed",
-        "data": {
-            "object": {
-                "id": factories.id("sess"),
-                "subscription": factories.id("sub"),
-                "client_reference_id": user.pk,
-            }
-        },
-    }
-    response = client.post(url, payload, content_type="application/json")
-    assert 201 == response.status_code
-    assert mock_stripe_checkout.Session.retrieve.call_count == 1
-
-    user.refresh_from_db()
-    assert paid_plan == user.customer.plan
-    assert user.customer.customer_id == session.customer.id
-    assert user.customer.payment_state == models.Customer.PaymentState.OK
-    assert (
-        session.subscription.current_period_end
-        == user.customer.current_period_end.timestamp()
-    )
-    assert "sub_paid" == user.customer.subscription_id
-    assert "paid.paying" == user.customer.state
-    assert (
-        models.StripeEvent.Status.PROCESSED == models.StripeEvent.objects.first().status
-    )
-
-
-def test_webhook_create_subscription_mismatched_customer_id(
-    client, user, session, mock_stripe_checkout
-):
-    """A mismatched customer_id returned from the Session should log an error and update the User's customer_id."""
-    url = reverse("billing:stripe_webhook")
-    user.customer.customer_id = "cus_mismatch"
-    user.customer.save()
-    payload = {
-        "id": "evt_test",
-        "object": "event",
-        "type": "checkout.session.completed",
-        "data": {
-            "object": {
-                "id": factories.id("sess"),
-                "subscription": factories.id("sub"),
-                "client_reference_id": user.pk,
-            }
-        },
-    }
-    response = client.post(url, payload, content_type="application/json")
-    assert 201 == response.status_code
-    assert mock_stripe_checkout.Session.retrieve.call_count == 1
-    user.refresh_from_db()
-    assert user.customer.customer_id == session.customer.id
-    assert (
-        models.StripeEvent.Status.PROCESSED == models.StripeEvent.objects.first().status
-    )
-
-
-def test_link_event_to_user(client, user, session):
-    url = reverse("billing:stripe_webhook")
-    payload = {
-        "id": "evt_test",
-        "object": "event",
-        "type": "checkout.session.completed",
-        "data": {
-            "object": {
-                "id": factories.id("sess"),
-                "subscription": factories.id("sub"),
-                "client_reference_id": user.pk,
-            }
-        },
-    }
-
-    response = client.post(url, payload, content_type="application/json")
-    assert response.status_code == 201
-    event = models.StripeEvent.objects.first()
-    assert event.user == user
-
-
-def test_get_checkout_session(client, user):
-    """GET to the CreateCheckoutSession endpoint will"""
